@@ -36,12 +36,12 @@
 *     License as published by the Free Software Foundation, either
 *     version 3 of the License, or (at your option) any later
 *     version.
-*     
+*
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU Lesser General Public License for more details.
-*     
+*
 *     You should have received a copy of the GNU Lesser General
 *     License along with this program.  If not, see
 *     <http://www.gnu.org/licenses/>.
@@ -64,5 +64,7 @@ int PG3DSetScreen( float );
 int PG3DForward( float );
 int PG3DAutoCamera( float[3], float[3] );
 int PG3DFindNearest( int, float *, float *, float *, int * );
+int PG3DGetCamera( float[3], float[3], float[3], float * );
+int PG3DRotateTarget( int, float );
 
 #endif
