@@ -200,6 +200,8 @@
 *           An integer identifier for the FITS TSC projection
 *        AST__HPX
 *           An integer identifier for the FITS HPX projection.
+*        AST__XPH
+*           An integer identifier for the FITS XPH projection.
 *        AST__TPN
 *           An integer identifier for a "TAN with correction terms" projection.
 *        AST__WCSBAD
@@ -230,20 +232,20 @@
 *     Research Councils
 
 *  Licence:
-*     This program is free software; you can redistribute it and/or
-*     modify it under the terms of the GNU General Public Licence as
-*     published by the Free Software Foundation; either version 2 of
-*     the Licence, or (at your option) any later version.
+*     This program is free software: you can redistribute it and/or
+*     modify it under the terms of the GNU Lesser General Public
+*     License as published by the Free Software Foundation, either
+*     version 3 of the License, or (at your option) any later
+*     version.
 *
-*     This program is distributed in the hope that it will be
-*     useful,but WITHOUT ANY WARRANTY; without even the implied
-*     warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-*     PURPOSE. See the GNU General Public Licence for more details.
+*     This program is distributed in the hope that it will be useful,
+*     but WITHOUT ANY WARRANTY; without even the implied warranty of
+*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*     GNU Lesser General Public License for more details.
 *
-*     You should have received a copy of the GNU General Public Licence
-*     along with this program; if not, write to the Free Software
-*     Foundation, Inc., 51 Franklin Street,Fifth Floor, Boston, MA
-*     02110-1301, USA
+*     You should have received a copy of the GNU Lesser General
+*     License along with this program.  If not, see
+*     <http://www.gnu.org/licenses/>.
 
 *  Authors:
 *     DSB: D.S. Berry (Starlink)
@@ -340,7 +342,8 @@
 #define AST__GLS 28
 #define AST__TPN 29
 #define AST__HPX 30
-#define AST__WCSBAD 31   /* A bad projection type */
+#define AST__XPH 31
+#define AST__WCSBAD 32   /* A bad projection type */
 
 /* Define a dummy __attribute__ macro for use on non-GNU compilers. */
 #ifndef __GNUC__
@@ -365,6 +368,7 @@ typedef struct AstWcsMap {
    int *np;                      /* Pointer to array of projection parameter counts */
    struct AstPrjPrm params;      /* WCS structure holding projection
                                     parameters, etc. Defined in proj.h */
+   int loncheck;                 /* Check returned longitude values? */
    int fits_proj;                /* Use as FITS-WCS projection? */
    int tpn_tan;                  /* Include TAN projection in TPN transformation? */
 } AstWcsMap;
@@ -399,6 +403,11 @@ typedef struct AstWcsMapVtab {
    void (* ClearFITSProj)( AstWcsMap *, int * );
    void (* SetFITSProj)( AstWcsMap *, int, int * );
 
+   int (* GetLonCheck)( AstWcsMap *, int * );
+   int (* TestLonCheck)( AstWcsMap *, int * );
+   void (* ClearLonCheck)( AstWcsMap *, int * );
+   void (* SetLonCheck)( AstWcsMap *, int, int * );
+
    int (* GetTPNTan)( AstWcsMap *, int * );
    int (* TestTPNTan)( AstWcsMap *, int * );
    void (* ClearTPNTan)( AstWcsMap *, int * );
@@ -475,6 +484,11 @@ void astInitWcsMapGlobals_( AstWcsMapGlobals * );
    void astClearFITSProj_( AstWcsMap *, int * );
    void astSetFITSProj_( AstWcsMap *, int, int * );
 
+   int astGetLonCheck_( AstWcsMap *, int * );
+   int astTestLonCheck_( AstWcsMap *, int * );
+   void astClearLonCheck_( AstWcsMap *, int * );
+   void astSetLonCheck_( AstWcsMap *, int, int * );
+
    int astGetTPNTan_( AstWcsMap *, int * );
    int astTestTPNTan_( AstWcsMap *, int * );
    void astClearTPNTan_( AstWcsMap *, int * );
@@ -552,6 +566,15 @@ astINVOKE(V,astSetFITSProj_(astCheckWcsMap(this),value,STATUS_PTR))
 #define astTestFITSProj(this) \
 astINVOKE(V,astTestFITSProj_(astCheckWcsMap(this),STATUS_PTR))
 
+#define astClearLonCheck(this) \
+astINVOKE(V,astClearLonCheck_(astCheckWcsMap(this),STATUS_PTR))
+#define astGetLonCheck(this) \
+astINVOKE(V,astGetLonCheck_(astCheckWcsMap(this),STATUS_PTR))
+#define astSetLonCheck(this,value) \
+astINVOKE(V,astSetLonCheck_(astCheckWcsMap(this),value,STATUS_PTR))
+#define astTestLonCheck(this) \
+astINVOKE(V,astTestLonCheck_(astCheckWcsMap(this),STATUS_PTR))
+
 #define astClearTPNTan(this) \
 astINVOKE(V,astClearTPNTan_(astCheckWcsMap(this),STATUS_PTR))
 #define astGetTPNTan(this) \
