@@ -10,7 +10,7 @@ require DynaLoader;
 use base qw| DynaLoader |;
 
 
-$VERSION = '1.05';
+$VERSION = '3.00';
 
 bootstrap Starlink::AST $VERSION;
 
@@ -251,6 +251,13 @@ sub Copy {
   return bless $new, ref($self);
 }
 
+sub FromString {
+  my $str = shift;
+  my $new = _FromString($str);
+  return unless defined $new;
+  return $new->_rebless();
+}
+
 # Converts a generic Starlink::AST object into the true
 # underlying class. Useful when we have extracted a pointer
 # from AST but do not yet know what type of object it is
@@ -298,17 +305,17 @@ sub STORABLE_thaw {
 
 package Starlink::AST::Axis;
 use base qw/ Starlink::AST /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::SkyAxis;
 use base qw/ Starlink::AST::Axis /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 # Channels need a wrapper
 
 package Starlink::AST::Channel;
 use base qw/ Starlink::AST  /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 sub new {
   # This should work for FitsChan and Channel and XmlChan
@@ -358,22 +365,26 @@ sub Read {
 
 package Starlink::AST::FitsChan;
 use base qw/ Starlink::AST::Channel /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::XmlChan;
 use base qw/ Starlink::AST::Channel /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::StcsChan;
 use base  qw/ Starlink::AST::Channel /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
+
+package Starlink::AST::MocChan;
+use base  qw/ Starlink::AST::Channel /;
+our $VERSION = '3.00';
 
 # Make this available for completeness and provide
 # a tie interface. Useful when transferring content via
 # a text file.
 package Starlink::AST::KeyMap;
 use base qw/ Starlink::AST /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 use Carp;
 # Need to convert the returned object(s) into a real object(s)
 
@@ -421,7 +432,7 @@ sub TIEHASH {
 }
 
 package Starlink::AST::KeyMap::Tie;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 use Scalar::Util qw/ blessed looks_like_number /;
 use Carp;
@@ -672,93 +683,135 @@ sub CLEAR {
 }
 
 
+package Starlink::AST::Table;
+use base qw/ Starlink::AST::KeyMap /;
+our $VERSION = '3.00';
+
+package Starlink::AST::FitsTable;
+use base qw/ Starlink::AST::Table /;
+our $VERSION = '3.00';
+
 package Starlink::AST::Mapping;
 use base qw/ Starlink::AST /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::CmpMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::DssMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::LutMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::GrismMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::IntraMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::MathMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::MatrixMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
+
+package Starlink::AST::NormMap;
+use base qw/ Starlink::AST::Mapping /;
+our $VERSION = '3.00';
 
 package Starlink::AST::PcdMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::PermMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::PolyMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
+
+sub PolyTran {
+  my $self = shift;
+  my $new = $self->_PolyTran(@_);
+  return bless $new, ref($self);
+}
+
+package Starlink::AST::ChebyMap;
+use base qw/ Starlink::AST::PolyMap /;
+our $VERSION = '3.00';
 
 package Starlink::AST::RateMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
+
+package Starlink::AST::SelectorMap;
+use base qw/ Starlink::AST::Mapping /;
+our $VERSION = '3.00';
 
 package Starlink::AST::ShiftMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::SlaMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::SphMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::SpecMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
+
+package Starlink::AST::SwitchMap;
+use base qw/ Starlink::AST::Mapping /;
+our $VERSION = '3.00';
 
 package Starlink::AST::UnitMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::WcsMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::WinMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::ZoomMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::TimeMap;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
+
+package Starlink::AST::TranMap;
+use base qw/ Starlink::AST::Mapping /;
+our $VERSION = '3.00';
+
+package Starlink::AST::UnitNormMap;
+use base qw/ Starlink::AST::Mapping /;
+our $VERSION = '3.00';
+
+package Starlink::AST::XphMap;
+use base qw/ Starlink::AST::Mapping /;
+our $VERSION = '3.00';
 
 package Starlink::AST::Frame;
 use base qw/ Starlink::AST::Mapping /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 # Wrapper for PickAxes
 # Uses context to decide whether to return the frame mapping or not
@@ -777,47 +830,75 @@ sub PickAxes {
 
 package Starlink::AST::Region;
 use base qw/ Starlink::AST::Frame /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::Circle;
 use base qw/ Starlink::AST::Region /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::Polygon;
 use base qw/ Starlink::AST::Region /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::Ellipse;
 use base qw/ Starlink::AST::Region /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::Box;
 use base qw/ Starlink::AST::Region /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::Interval;
 use base qw/ Starlink::AST::Region /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::CmpRegion;
 use base qw/ Starlink::AST::Region /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
+
+package Starlink::AST::Moc;
+use base qw/ Starlink::AST::Region /;
+our $VERSION = '3.00';
 
 package Starlink::AST::NullRegion;
 use base qw/ Starlink::AST::Region /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::Prism;
 use base qw/ Starlink::AST::Region /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
+
+package Starlink::AST::PointList;
+use base qw/ Starlink::AST::Region /;
+our $VERSION = '3.00';
+
+package Starlink::AST::Stc;
+use base qw/ Starlink::AST::Region /;
+our $VERSION = '3.00';
+
+package Starlink::AST::StcCatalogEntryLocation;
+use base qw/ Starlink::AST::Stc /;
+our $VERSION = '3.00';
+
+package Starlink::AST::StcResourceProfile;
+use base qw/ Starlink::AST::Stc /;
+our $VERSION = '3.00';
+
+package Starlink::AST::StcSearchLocation;
+use base qw/ Starlink::AST::Stc /;
+our $VERSION = '3.00';
+
+package Starlink::AST::StcObsDataLocation;
+use base qw/ Starlink::AST::Stc /;
+our $VERSION = '3.00';
 
 package Starlink::AST::FluxFrame;
 use base qw/ Starlink::AST::Frame /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::FrameSet;
 use base qw/ Starlink::AST::Frame /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 # Convert to proper class
 
@@ -850,7 +931,7 @@ sub FindFrameByDomain {
 
 package Starlink::AST::Plot;
 use base qw/ Starlink::AST::FrameSet /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 sub new {
   my $class = shift;
@@ -1015,28 +1096,89 @@ sub debug {
 
 }
 
+package Starlink::AST::Plot3D;
+use base qw/ Starlink::AST::Plot/;
+our $VERSION = '3.00';
+
+sub new {
+  my $class = shift;
+  my @args = @_;
+
+  my $gbox = $args[1];
+  my $pbox = $args[2];
+
+  # Call the underlying routine
+  my $self = $class->_new( @args );
+
+  $self->{_xglo} = $$gbox[0] if defined $$gbox[0];
+  $self->{_xghi} = $$gbox[3] if defined $$gbox[3];
+  $self->{_yglo} = $$gbox[1] if defined $$gbox[1];
+  $self->{_yghi} = $$gbox[4] if defined $$gbox[4];
+  $self->{_zglo} = $$gbox[2] if defined $$gbox[2];
+  $self->{_zghi} = $$gbox[5] if defined $$gbox[5];
+
+
+  $self->{_xplo} = $$pbox[0] if defined $$pbox[0];
+  $self->{_xphi} = $$pbox[3] if defined $$pbox[3];
+  $self->{_yplo} = $$pbox[1] if defined $$pbox[1];
+  $self->{_yphi} = $$pbox[4] if defined $$pbox[4];
+  $self->{_zplo} = $$pbox[2] if defined $$pbox[2];
+  $self->{_zphi} = $$pbox[5] if defined $$pbox[5];
+
+  return $self;
+}
+
+sub GBox {
+  my $self = shift;
+  if( @_ ) {
+     my $gbox = shift;
+     $self->{_xglo} = $$gbox[0];
+     $self->{_xghi} = $$gbox[3];
+     $self->{_yglo} = $$gbox[1];
+     $self->{_yghi} = $$gbox[4];
+     $self->{_zglo} = $$gbox[2];
+     $self->{_zghi} = $$gbox[5];
+
+  }
+  return ($self->{_xglo}, $self->{_xghi}, $self->{_yglo}, $self->{_yghi}, $self->{_zglo}, $self->{_zghi} );
+}
+
+sub PBox {
+  my $self = shift;
+  if( @_ ) {
+     my $pbox = shift;
+     $self->{_xplo} = $$pbox[0];
+     $self->{_xphi} = $$pbox[3];
+     $self->{_yplo} = $$pbox[1];
+     $self->{_yphi} = $$pbox[4];
+     $self->{_zplo} = $$pbox[2];
+     $self->{_zphi} = $$pbox[5];
+  }
+  return ($self->{_xplo}, $self->{_xphi}, $self->{_yplo}, $self->{_yphi}, $self->{_zplo}, $self->{_zphi} );
+}
+
 package Starlink::AST::CmpFrame;
 use base qw/ Starlink::AST::Frame /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::SkyFrame;
 use base qw/ Starlink::AST::Frame /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::SpecFrame;
 use base qw/ Starlink::AST::Frame /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::DSBSpecFrame;
 use base qw/ Starlink::AST::SpecFrame /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::SpecFluxFrame;
 use base qw/ Starlink::AST::CmpFrame /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 package Starlink::AST::TimeFrame;
 use base qw/ Starlink::AST::Frame /;
-our $VERSION = '1.00';
+our $VERSION = '3.00';
 
 1;
